import { SessionManager } from '@jupyterlab/services';
import { UUID } from '@lumino/coreutils';
export class Kernel {
    _kernelManager;
    _kernelName;
    _kernelConnection;
    _session;
    _clientId;
    _serverId;
    _sessionId;
    _info;
    constructor(props) {
        const { kernelManager, kernelName, kernelModel } = props;
        this._kernelManager = kernelManager;
        this._kernelName = kernelName;
        this._kernelConnection = this.requestJupyterKernel(kernelModel); // Request the effective Jupyter Kernel.
    }
    async requestJupyterKernel(kernelModel) {
        await this._kernelManager.ready;
        const sessionManager = new SessionManager({
            kernelManager: this._kernelManager,
            serverSettings: this._kernelManager.serverSettings,
            standby: 'never',
        });
        await sessionManager.ready;
        if (kernelModel) {
            console.log('Reusing a pre-existing kernel model.');
            const model = sessionManager.running().next().value;
            this._session = sessionManager.connectTo({ model });
        }
        else {
            const randomName = UUID.uuid4();
            this._session = await sessionManager.startNew({
                name: randomName,
                path: randomName,
                type: this._kernelName,
                kernel: {
                    name: this._kernelName,
                },
            }, {
                kernelConnectionOptions: {
                    handleComms: true,
                }
            });
        }
        this._info = await this._session.kernel.info;
        this._clientId = this._session.kernel.clientId;
        this._serverId = this._session.kernel.id;
        this._sessionId = this._session.id;
        return this._session.kernel;
    }
    get clientId() {
        return this._clientId;
    }
    get serverId() {
        return this._serverId;
    }
    get sessionId() {
        return this._sessionId;
    }
    get info() {
        return this._info;
    }
    get session() {
        return this._session;
    }
    get connection() {
        return this._kernelConnection;
    }
    shutdown() {
        this._session.kernel?.shutdown();
        this.connection.then(k => k.dispose());
    }
}
export default Kernel;
//# sourceMappingURL=Kernel.js.map